<!-- markdownlint-configure-file {"MD024": { "siblings_only": true } } -->
# Changelog

All notable changes to this library are documented in this file.

## **0.3.1** (4 Feb 2026)

### API Changes

- Replace `txyam2` dependency with `pymemcache` called from a thread (#140).

### New Features

### Bug Fixes

- Correct slack subscription logic when a new channel is joined (#136).

## **0.3.0** (4 Feb 2026)

First sane release of this code base onto pypi and hopefully conda-forge.
